@@ -1,17 +1,9 @@
 #
+# This file is part of POE::Component::Client::MPD.
+# Copyright (c) 2007 Jerome Quelin, all rights reserved.
+#
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# it under the same terms as Perl itself.
 #
 #
 
@@ -31,7 +23,7 @@ use base qw[ Class::Accessor::Fast ];
 __PACKAGE__->mk_accessors( qw[ _host _password _port  _version ] );
 
 
-our $VERSION = '0.5.1';
+our $VERSION = '0.5.2';
 
 
 #
@@ -143,11 +135,11 @@ sub spawn {
                 'pl.crop'              => '_onpub_crop',
                 '_crop_status'         => '_onpriv_crop_status',
                 # -- Playlist: changing playlist order
-# #                 shuffle
-# #                 swap
-# #                 swapid
-# #                 move
-# #                 moveid
+                'pl.shuffle'           => '_onpub_shuffle',
+                'pl.swap'              => '_onpub_swap',
+                'pl.swapid'            => '_onpub_swapid',
+                'pl.move'              => '_onpub_move',
+                'pl.moveid'            => '_onpub_moveid',
                 # -- Playlist: managing playlists
 # #                 load
 # #                 save
@@ -464,20 +456,9 @@ Jerome Quelin, C<< <jquelin at cpan.org> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007 Jerome Quelin, all rights reserved.
+Copyright (c) 2007 Jerome Quelin, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+it under the same terms as Perl itself.
 
 =cut
